@@ -1,15 +1,15 @@
 package Test::XML::Sig;
 use strict;
 use warnings;
-use namespace::autoclean ();
 
 use Test::Lib;
 
 # ABSTRACT: Test module for XML::Sig
 
 use Import::Into;
-
-use Test::XML::Sig::Util ();
+require Test::More;
+require Test::XML::Sig::Util;
+require XML::Sig;
 
 sub import {
 
@@ -17,9 +17,10 @@ sub import {
 
     my @imports = qw(
         Test::XML::Sig::Util
-        namespace::autoclean
         strict
         warnings
+        Test::More
+        XML::Sig
     );
 
     $_->import::into($caller_level) for @imports;
